<?php

/*
 * Let WordPress manage the document title.
 * By adding theme support, we declare that this theme does not use a
 * hard-coded <title> tag in the document head, and expect WordPress to
 * provide it for us.
 */
add_theme_support( 'title-tag' );


/* Register Thumbnails Size
================================== */

/* Recent Posts Widget */
add_image_size( 'recent-widget', 75, 50, true );


/* Register Custom Menu
==================================== */

register_nav_menu('primary', 'Main Menu');


/* Custom Background
==================================== */

add_theme_support( 'custom-background' );



/* Custom Headers
==================================== */

add_action( 'after_setup_theme', 'wpzoom_setup' );

if ( ! function_exists( 'wpzoom_setup' ) ):

function wpzoom_setup() {

  	define( 'HEADER_IMAGE', '%s/images/headers/mountain.jpeg' );
 	define( 'NO_HEADER_TEXT', true );

	// The height and width of your custom header.
 	define( 'HEADER_IMAGE_WIDTH', apply_filters( 'wpzoom_header_image_width', 1060 ) );
	define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'wpzoom_header_image_height', 326 ) );


	// Add a way for the custom header to be styled in the admin panel that controls
	// custom headers. See wpzoom_admin_header_style(), below.
	// add_custom_image_header( '', 'wpzoom_admin_header_style', 'wpzoom_admin_header_image' );

    add_theme_support( 'custom-header' );

	// ... and thus ends the changeable header business.

	// Default custom headers packaged with the theme. %s is a placeholder for the theme template directory URI.
	register_default_headers( array(
 		'mountain' => array(
			'url' => '%s/images/headers/mountain.jpeg',
			'thumbnail_url' => '%s/images/headers/mountain-thumb.jpeg',
 			'description' => __( 'Mountain', 'wpzoom' )
		),
        '2018' => array(
            'url' => '%s/images/headers/2018.jpg',
            'thumbnail_url' => '%s/images/headers/2018-thumb.jpg',
            'description' => __( '2018', 'wpzoom' )
        ),
		'balloon' => array(
			'url' => '%s/images/headers/balloon.jpg',
			'thumbnail_url' => '%s/images/headers/balloon-thumb.jpg',
 			'description' => __( 'Balloon', 'wpzoom' )
		),
		'balloon2' => array(
			'url' => '%s/images/headers/balloon2.jpg',
			'thumbnail_url' => '%s/images/headers/balloon2-thumb.jpg',
 			'description' => __( 'Balloon 2', 'wpzoom' )
		)
	) );
}
endif; // wpzoom_setup


if ( ! function_exists( 'wpzoom_admin_header_style' ) ) :
/**
  * Styles the header image displayed on the Appearance > Header admin panel.
  * Referenced via add_custom_image_header() in wpzoom_setup().
*/
function wpzoom_admin_header_style() {
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		border: none;
	}

 	#headimg img {
		max-width: 1000px;
		height: auto;
		width: 100%;
	}
	</style>
<?php
}
endif; // wpzoom_admin_header_style

if ( ! function_exists( 'wpzoom_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * Referenced via add_custom_image_header() in wpzoom_setup().
 */
function wpzoom_admin_header_image() { ?>
	<div id="headimg">

		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<img src="<?php echo esc_url( $header_image ); ?>" alt="" />
		<?php endif; ?>
	</div>
<?php }
endif; // wpzoom_admin_header_image


/* Custom Excerpt Length
==================================== */

function new_excerpt_length($length) {
	return (int) option::get("excerpt_length") ? (int) option::get("excerpt_length") : 50;
}
add_filter('excerpt_length', 'new_excerpt_length');



/* Reset Search Form
==================================== */

function my_search_form( $form ) {

    $form = '<form role="search" method="get" id="searchform" action="' . home_url( '/' ) . '" >
    <input type="text" value="' . get_search_query() . '" name="s" id="s" />
    <input type="submit" id="searchsubmit" value="'. esc_attr__('Search', 'wpzoom') .'" />
	</form>';

    return $form;
}

add_filter( 'get_search_form', 'my_search_form' );


/* Reset [gallery] shortcode styles
==================================== */

add_filter( 'gallery_style', function ( $a ) {
	return "<div class='gallery'>";
} );

/* Maximum width for images in posts
=========================================== */
if ( ! isset( $content_width ) ) $content_width = 640;



/*  Limit Posts
/*
/*  Plugin URI: http://labitacora.net/comunBlog/limit-post.phps
/*	Usage: the_content_limit($max_charaters, $more_link)
===================================================== */

function the_content_limit($max_char, $more_link_text = '(more...)', $stripteaser = 0, $more_file = '', $echo = true) {
    $content = get_the_content($more_link_text, $stripteaser, $more_file);
    $content = apply_filters('the_content', $content);
    $content = str_replace(']]>', ']]&gt;', $content);
    $content = strip_tags($content);

   if (strlen($_GET['p']) > 0 && $thisshouldnotapply) {
      echo $content;
   }
   else if ((strlen($content)>$max_char) && ($espacio = strpos($content, " ", $max_char ))) {
        $content = substr($content, 0, $espacio);
        if ($echo == true) { echo $content . "..."; } else {return $content; }
   }
   else {
      if ($echo == true) { echo $content . "..."; } else {return $content; }
   }
}

/* Comments Custom Template
==================================== */

function wpzoom_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'comment' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-author vcard">
			<?php echo get_avatar( $comment, 60 ); ?>
			<?php printf( __( '%s <span class="says">says:</span>', 'wpzoom' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>

			<div class="comment-meta commentmetadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
				<?php printf( __('%s at %s', 'wpzoom'), get_comment_date(), get_comment_time()); ?></a><?php edit_comment_link( __( '(Edit)', 'wpzoom' ), ' ' );
				?>

			</div><!-- .comment-meta .commentmetadata -->

		</div><!-- .comment-author .vcard -->
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'wpzoom' ); ?></em>
			<br />
		<?php endif; ?>



		<div class="comment-body"><?php comment_text(); ?></div>

		<div class="reply">
			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		</div><!-- .reply -->
	</div><!-- #comment-##  -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'wpzoom' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'wpzoom' ), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}

/* Breadcrumbs
============================= */

function wpzoom_breadcrumbs() {

  $delimiter = '&raquo;';
  $name = __('Home'); //text for the 'Home' link
  $currentBefore = '<span class="current">';
  $currentAfter = '</span>';

  if ( !is_home() && !is_front_page() || is_paged() ) {

     global $post;
    $home = get_bloginfo('url');
    echo '<a href="' . $home . '">' . $name . '</a> ' . $delimiter . ' ';

    if ( is_category() ) {
      global $wp_query;
      $cat_obj = $wp_query->get_queried_object();
      $thisCat = $cat_obj->term_id;
      $thisCat = get_category($thisCat);
      $parentCat = get_category($thisCat->parent);
      if ($thisCat->parent != 0) echo(get_category_parents($parentCat, TRUE, ' ' . $delimiter . ' '));
      echo $currentBefore . '';
      single_cat_title();
      echo '' . $currentAfter;

    } elseif ( is_day() ) {
      echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
      echo '<a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
      echo $currentBefore . get_the_time('d') . $currentAfter;

    } elseif ( is_month() ) {
      echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
      echo $currentBefore . get_the_time('F') . $currentAfter;

    } elseif ( is_year() ) {
      echo $currentBefore . get_the_time('Y') . $currentAfter;

    } elseif ( is_single() ) {
      $cat = get_the_category(); $cat = $cat[0];
      if ($cat)
      {
      echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
      }
      echo $currentBefore;
      //the_title();
      echo $currentAfter;

    } elseif ( is_page() && !$post->post_parent ) {
      echo $currentBefore;
      the_title();
      echo $currentAfter;

    } elseif ( is_page() && $post->post_parent ) {
      $parent_id  = $post->post_parent;
      $breadcrumbs = array();
      while ($parent_id) {
        $page = get_page($parent_id);
        $breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
        $parent_id  = $page->post_parent;
      }
      $breadcrumbs = array_reverse($breadcrumbs);
      foreach ($breadcrumbs as $crumb) echo $crumb . ' ' . $delimiter . ' ';
      echo $currentBefore;
      the_title();
      echo $currentAfter;

    } elseif ( is_search() ) {
      echo $currentBefore . __('Search results for &#39;', 'wpzoom') . get_search_query() . '&#39;' . $currentAfter;

    } elseif ( is_tag() ) {
      echo $currentBefore . __('Posts tagged &#39;', 'wpzoom');
      single_tag_title();
      echo '&#39;' . $currentAfter;

    } elseif ( is_author() ) {
       global $author;
      $userdata = get_userdata($author);
      echo $currentBefore . __('Articles posted by ', 'wpzoom') . $userdata->display_name . $currentAfter;

    } elseif ( is_404() ) {
      echo $currentBefore . __('Error 404', 'wpzoom') . $currentAfter;
    }

    if ( get_query_var('paged') ) {
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
      echo __('Page') . ' ' . get_query_var('paged');
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
    }

  }
}


function meeta_styles() {

    // Load our main stylesheet.
    wp_enqueue_style( 'meeta-style', get_stylesheet_uri(), array(), WPZOOM::$themeVersion );

    wp_enqueue_style( 'meeta-google-font-default', 'https://fonts.googleapis.com/css?family=Roboto:400,400i,500,500i,700,700i&amp;subset=cyrillic,greek,latin-ext' );

    wp_enqueue_style( 'dashicons' );

    wp_enqueue_script( 'dropdown', get_template_directory_uri() . '/js/dropdown.js', array( 'jquery' ), WPZOOM::$themeVersion, true );

}

add_action( 'wp_enqueue_scripts', 'meeta_styles' );
